@@ -7,6 +7,9 @@
 #include <errno.h>
 #include <stddef.h>
 #include <unistd.h>
+#if __has_include(<sys/random.h>)
+#include <sys/random.h>
+#endif
 #ifdef _WIN32
 #define WIN32_LEAN_AND_MEAN
 #include <Windows.h>
