@@ -6,10 +6,7 @@
 
 #if __has_include(<sched.h>)
 #include <sched.h>
-#endif
-
-
-#ifdef _WIN32
+#elif defined(_WIN32)
 #define WIN32_LEAN_AND_MEAN
 #include <Windows.h>
 static int sched_yield() {
